@@ -1,7 +1,7 @@
 /*
  *  display.c - code for this nifty display.
  *	part of galculator
- *  	(c) 2002-2004 Simon Floery (chimaira@users.sf.net)
+ *  	(c) 2002-2006 Simon Floery (chimaira@users.sf.net)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -64,7 +64,7 @@ gboolean on_textview_button_press_event (GtkWidget *widget,
 	int			x, y;
 	GtkTextIter		start, end;
 	char 			*selected_text;
-	
+
 	if (event->button == 1)	{
 		gtk_widget_get_pointer (widget, &x, &y);
 		gtk_text_view_get_iter_at_location (view, &start, x, y);
@@ -113,8 +113,8 @@ void on_textview_selection_received (GtkWidget *widget,
 	
 	/* Make sure we got the data in the expected form */
 	if (data->type != GDK_SELECTION_TYPE_STRING) return;
-	
-	display_result_feed (data->data);
+
+	display_result_feed ((char *)data->data);
 
 	return;
 }
