@@ -1,7 +1,7 @@
 /*
  *  display.h
  *	part of galculator
- *  	(c) 2002-2003 Simon Floery (chimaira@users.sf.net)
+ *  	(c) 2002-2006 Simon Floery (chimaira@users.sf.net)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -77,16 +77,18 @@ void display_module_notation_activate (int mode);
 void display_result_add_digit (char digit);
 void display_result_set (char *string_value);
 void display_result_set_double (double value);
-void display_result_set_radiant (double value);
 void display_result_feed (char *string);
+char *display_get_line (int line_nr);
 char *display_result_get ();
 double display_result_get_double ();
-double display_result_get_rad_angle ();
 void display_append_e (GtkToggleButton *button);
 void display_result_toggle_sign (GtkToggleButton *button);
 void display_result_backspace ();
+void display_result_getset ();
 
 void display_set_line_double (double value, int line, char *tag);
+void display_set_line (char *string, int line, char *tag);
+
 void display_stack_create ();
 void display_stack_remove ();
 void display_stack_set_yzt (char **stack);
