@@ -1,7 +1,7 @@
 /*
  *  ui.c - general user interface code.
  *	part of galculator
- *  	(c) 2002-2004 Simon Floery (chimaira@users.sf.net)
+ *  	(c) 2002-2006 Simon Floery (chimaira@users.sf.net)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -34,10 +34,10 @@
 #include <gtk/gtk.h>
 #include <glade/glade.h>
 
-GladeXML	*main_window_xml, *dispctrl_xml, *button_box_xml, *prefs_xml, 
-		*about_dialog_xml;
+GladeXML	*main_window_xml=NULL, *dispctrl_xml=NULL, *button_box_xml=NULL, 
+		*prefs_xml=NULL, *about_dialog_xml=NULL;
 char		dec_point[2];
-GtkListStore	*prefs_constant_store, *prefs_user_function_store;
+GtkListStore	*prefs_constant_store=NULL, *prefs_user_function_store=NULL;
 
 static void set_disp_ctrl_object_data ();
 static void set_all_dispctrl_buttons_property (GFunc func, gpointer data);
@@ -313,7 +313,8 @@ void ui_main_window_set_dispctrl (int location)
 	if (dispctrl_xml) {
 		table_dispctrl = glade_xml_get_widget (dispctrl_xml, "table_dispctrl");
 		if (table_dispctrl) gtk_widget_destroy (table_dispctrl); 
-		g_free (dispctrl_xml);
+		g_object_unref (G_OBJECT(dispctrl_xml));
+		dispctrl_xml = NULL;
 	}	
 	/* now create the new one at location */
 	switch(location) {
@@ -377,19 +378,20 @@ void ui_main_window_buttons_create (int mode)
 	s_signal_cb	signal_cb;
 	
 	if (mode == BASIC_MODE) {
+		if (button_box_xml) g_object_unref (G_OBJECT(button_box_xml));
 		button_box_xml = glade_file_open (BASIC_GLADE_FILE, "button_box", TRUE);
 		box = glade_xml_get_widget (main_window_xml, "window_vbox");
 		ui_pack_from_xml (box, 4, button_box_xml, "button_box", 
 			"button_1", TRUE, TRUE);
 		set_basic_object_data (button_box_xml);
 	} else if (mode == SCIENTIFIC_MODE) {
+		if (button_box_xml) g_object_unref (G_OBJECT(button_box_xml));
 		button_box_xml = glade_file_open (SCIENTIFIC_GLADE_FILE, "button_box", TRUE);
 		box = glade_xml_get_widget (main_window_xml, "window_vbox");
 		ui_pack_from_xml (box, 4, button_box_xml, "button_box", 
 			"button_1", TRUE, TRUE);
 		set_scientific_object_data (button_box_xml);
 	} else error_message ("Unknown mode in \"ui_main_window_buttons_create\"");
-
 	signal_cb.detailed_signal = g_strdup ("button_press_event");
 	signal_cb.callback = (GCallback) on_button_press_event;
 	set_all_normal_buttons_property (set_table_child_callback, (gpointer) &signal_cb);
@@ -923,17 +925,7 @@ GtkWidget *ui_pref_dialog_create ()
 		glade_xml_get_widget (prefs_xml, "prefs_func_delete_button"));
 	gtk_size_group_add_widget (sgroup,
 		glade_xml_get_widget (prefs_xml, "prefs_func_clear_button"));
-	
-	sgroup = gtk_size_group_new (GTK_SIZE_GROUP_HORIZONTAL);
-	gtk_size_group_add_widget (sgroup, 
-		glade_xml_get_widget (prefs_xml, "prefs_hex_bits_label"));
-	gtk_size_group_add_widget (sgroup,
-		glade_xml_get_widget (prefs_xml, "prefs_oct_bits_label"));
-	gtk_size_group_add_widget (sgroup,
-		glade_xml_get_widget (prefs_xml, "prefs_bin_bits_label"));
-	gtk_size_group_add_widget (sgroup,
-		glade_xml_get_widget (prefs_xml, "prefs_bin_fixed"));
-	
+
 	gtk_widget_show (prefs_dialog);
 	return prefs_dialog;
 }
