@@ -1,7 +1,7 @@
 /*
  *  ui.h - general user interface code.
  *	part of galculator
- *  	(c) 2002-2003 Simon Floery (chimaira@users.sf.net)
+ *  	(c) 2002-2006 Simon Floery (chimaira@users.sf.net)
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,7 +23,7 @@ extern GladeXML 	*button_box_xml;
 extern GladeXML 	*prefs_xml;
 extern GladeXML 	*about_dialog_xml;
 extern GladeXML		*dispctrl_xml;
-extern GtkListStore	*store;
+extern GtkListStore	*prefs_constant_store, *prefs_user_function_store;
 extern char		dec_point[2];
 
 /* active_buttons flags */
@@ -31,32 +31,49 @@ extern char		dec_point[2];
 #define AB_HEX 1 << CS_HEX
 #define AB_OCT 1 << CS_OCT
 #define AB_BIN 1 << CS_BIN
-#define AB_PAN 1 << (CS_PAN + NR_NUMBER_BASES)
-#define AB_RPN 1 << (CS_RPN + NR_NUMBER_BASES)
 
 typedef struct {
 	char		*button_name;
 	unsigned int	mask;
 } s_active_buttons;
 
+typedef struct {
+	const gchar 	*detailed_signal;
+	GCallback	callback;
+} s_signal_cb;
+	
+
 GtkWidget *ui_main_window_create ();
 void ui_main_window_set_dispctrl (int location);
 void ui_main_window_buttons_destroy ();
 void ui_main_window_buttons_create (int mode);
+void set_all_buttons_callback (gpointer *data);
 void set_all_buttons_size (int width, int height);
 void set_all_buttons_font (char *font_string);
 void update_active_buttons (int number_base, int notation_mode);
+void update_dispctrl ();
 void button_activation (GtkToggleButton *b);
 gboolean button_deactivation (gpointer data);
 GtkWidget *ui_pref_dialog_create ();
 GtkWidget *ui_about_dialog_create();
 GtkWidget *ui_font_dialog_create (char *title, GtkButton *button);
 GtkWidget *ui_color_dialog_create (char *title, GtkButton *button);
+GtkWidget *ui_user_functions_menu_create (s_user_function *user_function, 
+				GCallback user_function_handler);
 GtkWidget *ui_constants_menu_create (s_constant *constant, 
 				GCallback const_handler);
 GtkWidget *ui_memory_menu_create (s_array memory, 
 				GCallback const_handler, 
 				char *last_item);
+GtkWidget *ui_right_mouse_menu_create ();
+void ui_formula_entry_activate ();
+void ui_formula_entry_set (G_CONST_RETURN gchar *text);
+void ui_formula_entry_insert (G_CONST_RETURN gchar *text);
+void ui_formula_entry_backspace ();
+void ui_formula_entry_state ();
+void ui_button_set_pan ();
+void ui_button_set_rpn ();
+void ui_relax_fmod_buttons ();
 void position_menu (GtkMenu *menu, 
 		gint *x, 
 		gint *y, 
